Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 31 fields pub NVIC: Nvic, pub SCB: Scb, pub SYSTICK: SysTick, pub ADPLLDIG: Adplldig, pub ANAMISC: Anamisc, pub BLE: Ble, pub CHIP_VERSION: ChipVersion, pub CRG_AON: CrgAon, pub CRG_TIM: CrgTim, pub CRG_TOP: CrgTop, pub GPADC: Gpadc, pub GPIO: Gpio, pub GPREG: Gpreg, pub I2C: I2C, pub KBRD: Kbrd, pub MBIST_SRAM12: MbistSram12, pub MBIST_SRAM3: MbistSram3, pub OTPC: Otpc, pub PATCH: Patch, pub QUADEC: Quadec, pub RFCU: Rfcu, pub RFCU_POWER: RfcuPower, pub RFMON: Rfmon, pub RTC: Rtc, pub SPI: Spi, pub SYS_WDOG: SysWdog, pub TIMER0: Timer0, pub TIMER1: Timer1, pub UART: Uart, pub UART2: Uart2, pub WKUP: Wkup,
}
Required for compatibility with RTIC and other frameworks

Fields

NVIC: NvicSCB: ScbSYSTICK: SysTickADPLLDIG: AdplldigANAMISC: AnamiscBLE: BleCHIP_VERSION: ChipVersionCRG_AON: CrgAonCRG_TIM: CrgTimCRG_TOP: CrgTopGPADC: GpadcGPIO: GpioGPREG: GpregI2C: I2CKBRD: KbrdMBIST_SRAM12: MbistSram12MBIST_SRAM3: MbistSram3OTPC: OtpcPATCH: PatchQUADEC: QuadecRFCU: RfcuRFCU_POWER: RfcuPowerRFMON: RfmonRTC: RtcSPI: SpiSYS_WDOG: SysWdogTIMER0: Timer0TIMER1: Timer1UART: UartUART2: Uart2WKUP: Wkup

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks