Timer1StatusReg

Type Alias Timer1StatusReg 

pub type Timer1StatusReg = RegValueT<Timer1StatusReg_SPEC>;
Timer1 counter value

Aliased Type

pub struct Timer1StatusReg { /* private fields */ }

Implementations

Source

impl Timer1StatusReg

pub fn timer1_in2_ovrflw( self, ) -> RegisterFieldBool<15, 1, 0, Timer1StatusReg_SPEC, R>

1 = New IN2 event occurred while Interrupt was pending. TIMER1_CAPCNT2_VALUE_REG gives the time stamp of the first event.

pub fn timer1_in1_ovrflw( self, ) -> RegisterFieldBool<14, 1, 0, Timer1StatusReg_SPEC, R>

1 = New IN1 event occurred while Interrupt was pending. TIMER1_CAPCNT1_VALUE_REG gives the time stamp of the first event.

pub fn timer1_in2_event( self, ) -> RegisterFieldBool<13, 1, 0, Timer1StatusReg_SPEC, R>

1 = Pending Capture 2 interrupt. It has be clear writing 1 to TIMER1_CLR_IN2_EVENT

pub fn timer1_in1_event( self, ) -> RegisterFieldBool<12, 1, 0, Timer1StatusReg_SPEC, R>

1 = Pending Capture 1 interrupt. It has be clear writing 1 to TIMER1_CLR_IN1_EVENT

pub fn timer1_timer_event( self, ) -> RegisterFieldBool<11, 1, 0, Timer1StatusReg_SPEC, R>

1 = Pending Timer interrupt. it has be clear writing 1’ to TIMER1_CLR_TIMER_EVENT

pub fn timer1_timer_value( self, ) -> RegisterField<0, 0x7ff, 1, 0, u16, u16, Timer1StatusReg_SPEC, R>

Gives the current timer value