pub type Timer1CaptureReg = RegValueT<Timer1CaptureReg_SPEC>;Expand description
Timer1 Capture control register
Aliased Type
pub struct Timer1CaptureReg { /* private fields */ }Implementations
Sourceimpl Timer1CaptureReg
impl Timer1CaptureReg
Sourcepub fn timer1_in2_stamp_type(
self,
) -> RegisterFieldBool<27, 1, 0, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in2_stamp_type( self, ) -> RegisterFieldBool<27, 1, 0, Timer1CaptureReg_SPEC, RW>
0 = On each event store the counter value 1 = On each event store the RTC time stamp
Sourcepub fn timer1_in2_period_max(
self,
) -> RegisterField<21, 0x3f, 1, 0, u8, u8, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in2_period_max( self, ) -> RegisterField<21, 0x3f, 1, 0, u8, u8, Timer1CaptureReg_SPEC, RW>
Gives the number of periods +1 of IN2, in which module counts
Sourcepub fn timer1_in2_irq_en(
self,
) -> RegisterFieldBool<20, 1, 0, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in2_irq_en( self, ) -> RegisterFieldBool<20, 1, 0, Timer1CaptureReg_SPEC, RW>
1 = Interrupt is generated when capture is occurred or was counted TIMER1_IN2_PERIOD_MAX 0 = Interrupt is masked
Sourcepub fn timer1_in2_count_en(
self,
) -> RegisterFieldBool<19, 1, 0, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in2_count_en( self, ) -> RegisterFieldBool<19, 1, 0, Timer1CaptureReg_SPEC, RW>
0 = Capture mode 1 = Count mode
Sourcepub fn timer1_in2_event_fall_en(
self,
) -> RegisterFieldBool<18, 1, 0, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in2_event_fall_en( self, ) -> RegisterFieldBool<18, 1, 0, Timer1CaptureReg_SPEC, RW>
0 = Rising edge event 1 = Falling edge event it should be written when TIMER1_GPIO2_CONF=0 to prevent false events
Sourcepub fn timer1_gpio2_conf(
self,
) -> RegisterField<14, 0xf, 1, 0, u8, u8, Timer1CaptureReg_SPEC, RW>
pub fn timer1_gpio2_conf( self, ) -> RegisterField<14, 0xf, 1, 0, u8, u8, Timer1CaptureReg_SPEC, RW>
0,13,14,15 = IN2 is not used 1..12 = Defines the P0 pin (0..11) module will use as IN2
Sourcepub fn timer1_in1_stamp_type(
self,
) -> RegisterFieldBool<13, 1, 0, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in1_stamp_type( self, ) -> RegisterFieldBool<13, 1, 0, Timer1CaptureReg_SPEC, RW>
0 = On each event store the counter value 1 = On each event store the RTC time stamp
Sourcepub fn timer1_in1_period_max(
self,
) -> RegisterField<7, 0x3f, 1, 0, u8, u8, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in1_period_max( self, ) -> RegisterField<7, 0x3f, 1, 0, u8, u8, Timer1CaptureReg_SPEC, RW>
Gives the number of periods +1 of IN1, in which module counts
Sourcepub fn timer1_in1_irq_en(
self,
) -> RegisterFieldBool<6, 1, 0, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in1_irq_en( self, ) -> RegisterFieldBool<6, 1, 0, Timer1CaptureReg_SPEC, RW>
1 = Interrupt is generated when capture is occurred or was counted TIMER1_IN1_PERIOD_MAX 0 = Interrupt is masked
Sourcepub fn timer1_in1_count_en(
self,
) -> RegisterFieldBool<5, 1, 0, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in1_count_en( self, ) -> RegisterFieldBool<5, 1, 0, Timer1CaptureReg_SPEC, RW>
0 = Capture mode 1 = Count mode
Sourcepub fn timer1_in1_event_fall_en(
self,
) -> RegisterFieldBool<4, 1, 0, Timer1CaptureReg_SPEC, RW>
pub fn timer1_in1_event_fall_en( self, ) -> RegisterFieldBool<4, 1, 0, Timer1CaptureReg_SPEC, RW>
0 = Rising edge event 1 = Falling edge event it should be written when TIMER1_GPIO1_CONF=0 to prevent false events
Sourcepub fn timer1_gpio1_conf(
self,
) -> RegisterField<0, 0xf, 1, 0, u8, u8, Timer1CaptureReg_SPEC, RW>
pub fn timer1_gpio1_conf( self, ) -> RegisterField<0, 0xf, 1, 0, u8, u8, Timer1CaptureReg_SPEC, RW>
0,13,14,15 = IN1 is not used 1..12 = Defines the P0 pin (0..11) module will use as IN1